==> foundation-ui-components-1.15.0.tgz: package/src/common/card/specs/NsMediumCard.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import NsMediumCard from '../NsMediumCard';

describe('NsMediumCard component', () => {
    const props = {
        title: 'Sustainability',
        titleFontWeight: 'bold' as 'bold',
        subtitle:
            'We’re committed to keeping our global communities clean, safe, and protected for the future. We’re proud to embrace sustainable practices today for a resource-rich tomorrow.',
        button: {
            showButton: true,
            buttonText: 'SEE WHAT WE’RE DOING',
            buttonVariant: 'outlined' as 'outlined',
            buttonColor: 'secondary' as 'secondary',
            url: '#',
        },
        backgroundImageUrl: 'https://media.nuskin.com/m/3353b9c05cb83860/Small-category-facial_moisturizers.jpg',
        backgroundImageAlt: 'Lumi Spa',
    };

    it('1. renders with correct content and styles', () => {
        render(<NsMediumCard {...props} />);

        const mediumCard = screen.getByTestId('medium-card');
        expect(mediumCard).toBeInTheDocument();

        const titleElement = screen.getByText('Sustainability');
        expect(titleElement).toBeInTheDocument();

        const subtitleElement = screen.getByText(
            'We’re committed to keeping our global communities clean, safe, and protected for the future. We’re proud to embrace sustainable practices today for a resource-rich tomorrow.'
        );
        expect(subtitleElement).toBeInTheDocument();

        const imageElement = screen.getByAltText('Lumi Spa');
        expect(imageElement).toBeInTheDocument();

        const button = screen.queryByText('SEE WHAT WE’RE DOING');
        expect(button).toBeInTheDocument();
    });

    it('2. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        const { container } = render(<NsMediumCard {...updatedProps} />);

        const button = container.querySelector('.cta');
        expect(button).toBeNull();
    });
});

==> foundation-ui-components-1.30.1.tgz: package/src/common/card/specs/NsMediumCard.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import NsMediumCard from '../NsMediumCard';
import { ImageData1 } from '../fixtures/ImageData1';

describe('NsMediumCard component', () => {
    const props = {
        title: 'Sustainability',
        titleFontWeight: 'bold' as 'bold',
        subtitle:
            'We’re committed to keeping our global communities clean, safe, and protected for the future. We’re proud to embrace sustainable practices today for a resource-rich tomorrow.',
        button: {
            showButton: true,
            buttonText: 'SEE WHAT WE’RE DOING',
            buttonVariant: 'outlined' as 'outlined',
            buttonColor: 'secondary' as 'secondary',
            url: '#',
        },
        backgroundImageDetail: ImageData1,
    };

    it('1. renders with correct content and styles', () => {
        render(<NsMediumCard {...props} />);

        const mediumCard = screen.getByTestId('medium-card');
        expect(mediumCard).toBeInTheDocument();

        const titleElement = screen.getByText('Sustainability');
        expect(titleElement).toBeInTheDocument();

        const subtitleElement = screen.getByText(
            'We’re committed to keeping our global communities clean, safe, and protected for the future. We’re proud to embrace sustainable practices today for a resource-rich tomorrow.'
        );
        expect(subtitleElement).toBeInTheDocument();

        const imageElement = screen.getByAltText(ImageData1.selected?.altText || '');
        expect(imageElement).toBeInTheDocument();

        const button = screen.queryByText('SEE WHAT WE’RE DOING');
        expect(button).toBeInTheDocument();
    });

    it('2. does not render button when button prop is false', () => {
        let updatedProps = { ...props };
        updatedProps.button.showButton = false;
        const { container } = render(<NsMediumCard {...updatedProps} />);

        const button = container.querySelector('.cta');
        expect(button).toBeNull();
    });
});
